@@ -1,5 +1,5 @@
 /* Test the Unicode character type functions.
-   Copyright (C) 2007-2008 Free Software Foundation, Inc.
+   Copyright (C) 2007-2009 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -18,22 +18,9 @@
 
 #include "unictype.h"
 
-#include <stdio.h>
-#include <stdlib.h>
 #include <string.h>
 
-#define ASSERT(expr) \
-  do									     \
-    {									     \
-      if (!(expr))							     \
-        {								     \
-          fprintf (stderr, "%s:%d: assertion failed\n", __FILE__, __LINE__); \
-          fflush (stderr);						     \
-          abort ();							     \
-        }								     \
-    }									     \
-  while (0)
-#define SIZEOF(a) (sizeof(a) / sizeof(a[0]))
+#include "macros.h"
 
 static const struct { unsigned int ch; int value; } mapping[] =
   {
@@ -50,7 +37,7 @@ main ()
   for (i = 0; i < SIZEOF (mapping); i++)
     {
       for (; c < mapping[i].ch; c++)
-	ASSERT (uc_digit_value (c) == -1);
+        ASSERT (uc_digit_value (c) == -1);
       /* Here c = mapping[i].ch.  */
       ASSERT (uc_digit_value (c) == mapping[i].value);
       c++;
